==> react-lds-8.7.0.tgz: package/es/components/Menu/ControlledMenu.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.object.set-prototype-of";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.string.starts-with";
import "core-js/modules/es7.array.includes";
import "core-js/modules/es6.string.includes";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import omit from 'lodash-es/omit';
import { getUniqueHash } from '../../utils';
import MenuItem from './MenuItem';
var propTypes = {
  /**
   * The button that triggers the dropdown menu
   */
  button: PropTypes.element.isRequired,

  /**
   * set to true if menuitems should be menuitemcheckboxes
   */
  checkbox: PropTypes.bool,

  /**
   * should be MenuItems or MenuSubHeaders
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * sets the number of items being displayed. 5, 7, or 10
   */
  height: PropTypes.oneOf([5, 7, 10]),

  /**
   * use this instead of height if an leftIcon is on every item. 5, 7, or 10
   */
  heightIcon: PropTypes.oneOf([5, 7, 10]),

  /**
   * open or closed menu dropdown
   */
  isOpen: PropTypes.bool,

  /**
   * indicates that this is the last element inside a button group and renders
   * the required css class
   */
  last: PropTypes.bool,

  /**
   * displays the nubbin at the correct position if true, hidden per default
   */
  nubbin: PropTypes.bool,

  /**
   * use onSelect instead of onClick on the MenuItems if you want reduce the number of event listeners
   */
  onSelect: PropTypes.func,

  /**
   * position relative to the menu button
   */
  position: PropTypes.oneOf(['top-left', 'top-left-corner', 'top', 'top-right', 'top-right-corner', 'bottom-left', 'bottom-left-corner', 'bottom', 'bottom-right', 'bottom-right-corner']),

  /**
   * render the dropdown even when it is closed
   */
  renderClosedDropdown: PropTypes.bool,

  /**
   * Can be used to prepend an arbitrary menu header
   */
  renderHeader: PropTypes.func,

  /**
   * length of the menu box. 'small', 'medium', or 'large'
   */
  size: PropTypes.oneOf(['small', 'medium', 'large'])
};

var ControlledMenu =
/*#__PURE__*/
function (_Component) {
  _inherits(ControlledMenu, _Component);

  function ControlledMenu() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, ControlledMenu);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(ControlledMenu)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "handleItemClick", function (event) {
      var onSelect = _this.props.onSelect;
      var value = event.target.dataset.value;

      if (value) {
        onSelect(value, event);
        event.stopPropagation(); // stopPropagation so we can have nested menus
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderChildren", function () {
      var _this$props = _this.props,
          children = _this$props.children,
          checkbox = _this$props.checkbox;
      return React.Children.map(children, function (child, index) {
        var id = getUniqueHash('item', index);
        if (!child) return null;

        if (child.type !== MenuItem) {
          return React.cloneElement(child, {
            key: id
          });
        }

        return React.cloneElement(child, {
          selected: checkbox ? child.props.selected === true : null,
          key: id
        });
      });
    });

    return _this;
  }

  _createClass(ControlledMenu, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          button = _this$props2.button,
          children = _this$props2.children,
          className = _this$props2.className,
          height = _this$props2.height,
          heightIcon = _this$props2.heightIcon,
          isOpen = _this$props2.isOpen,
          last = _this$props2.last,
          nubbin = _this$props2.nubbin,
          onSelect = _this$props2.onSelect,
          position = _this$props2.position,
          renderClosedDropdown = _this$props2.renderClosedDropdown,
          renderHeader = _this$props2.renderHeader,
          size = _this$props2.size;
      var wrapperClasses = ['slds-dropdown-trigger', 'slds-dropdown-trigger_click', {
        'slds-button_last': last
      }, {
        'slds-is-open': isOpen
      }];
      var dropdownClasses = ['slds-dropdown', _defineProperty({}, "slds-dropdown_".concat(size), size), {
        'slds-dropdown_left': position.includes('left')
      }, {
        'slds-dropdown_right': position.includes('right')
      }, {
        'slds-dropdown_bottom': position.startsWith('bottom')
      }, _defineProperty({}, "slds-nubbin_".concat(position), nubbin), className];
      var listClasses = [_defineProperty({}, "slds-dropdown_length-".concat(height), height), _defineProperty({}, "slds-dropdown_length-with-icon-".concat(heightIcon), heightIcon), 'slds-dropdown__list'];
      var rest = omit(this.props, Object.keys(propTypes));
      return React.createElement("div", _extends({
        className: cx(wrapperClasses)
      }, rest), button, (isOpen || renderClosedDropdown) && React.createElement("div", {
        className: cx(dropdownClasses)
      }, renderHeader && renderHeader(), children && React.createElement("ul", {
        className: cx(listClasses),
        role: "menu",
        onClick: onSelect ? this.handleItemClick : null
      }, this.renderChildren())));
    }
  }]);

  return ControlledMenu;
}(Component);

_defineProperty(ControlledMenu, "defaultProps", {
  className: null,
  checkbox: false,
  height: null,
  heightIcon: null,
  isOpen: false,
  last: false,
  nubbin: false,
  onSelect: null,
  position: 'top-left',
  renderHeader: null,
  renderClosedDropdown: false,
  size: 'small'
});

ControlledMenu.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
export default ControlledMenu;

==> react-lds-9.1.0.tgz: package/es/components/Menu/ControlledMenu.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.includes";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.array.map";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.includes";
import "core-js/modules/es.string.iterator";
import "core-js/modules/es.string.starts-with";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import omit from 'lodash-es/omit';
import { getUniqueHash } from '../../utils';
import MenuItem from './MenuItem';
var propTypes = {
  /**
   * The button that triggers the dropdown menu
   */
  button: PropTypes.element.isRequired,

  /**
   * set to true if menuitems should be menuitemcheckboxes
   */
  checkbox: PropTypes.bool,

  /**
   * should be MenuItems or MenuSubHeaders
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * sets the number of items being displayed. 5, 7, or 10
   */
  height: PropTypes.oneOf([5, 7, 10]),

  /**
   * use this instead of height if an leftIcon is on every item. 5, 7, or 10
   */
  heightIcon: PropTypes.oneOf([5, 7, 10]),

  /**
   * open or closed menu dropdown
   */
  isOpen: PropTypes.bool,

  /**
   * indicates that this is the last element inside a button group and renders
   * the required css class
   */
  last: PropTypes.bool,

  /**
   * displays the nubbin at the correct position if true, hidden per default
   */
  nubbin: PropTypes.bool,

  /**
   * use onSelect instead of onClick on the MenuItems if you want reduce the number of event listeners
   */
  onSelect: PropTypes.func,

  /**
   * position relative to the menu button
   */
  position: PropTypes.oneOf(['top-left', 'top-left-corner', 'top', 'top-right', 'top-right-corner', 'bottom-left', 'bottom-left-corner', 'bottom', 'bottom-right', 'bottom-right-corner']),

  /**
   * render the dropdown even when it is closed
   */
  renderClosedDropdown: PropTypes.bool,

  /**
   * Can be used to prepend an arbitrary menu header
   */
  renderHeader: PropTypes.func,

  /**
   * length of the menu box. 'small', 'medium', or 'large'
   */
  size: PropTypes.oneOf(['small', 'medium', 'large'])
};

var ControlledMenu =
/*#__PURE__*/
function (_Component) {
  _inherits(ControlledMenu, _Component);

  function ControlledMenu() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, ControlledMenu);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(ControlledMenu)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "handleItemClick", function (event) {
      var onSelect = _this.props.onSelect;
      var value = event.target.dataset.value;

      if (value) {
        onSelect(value, event);
        event.stopPropagation(); // stopPropagation so we can have nested menus
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderChildren", function () {
      var _this$props = _this.props,
          children = _this$props.children,
          checkbox = _this$props.checkbox;
      return React.Children.map(children, function (child, index) {
        var id = getUniqueHash('item', index);
        if (!child) return null;

        if (child.type !== MenuItem) {
          return React.cloneElement(child, {
            key: id
          });
        }

        return React.cloneElement(child, {
          selected: checkbox ? child.props.selected === true : null,
          key: id
        });
      });
    });

    return _this;
  }

  _createClass(ControlledMenu, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          button = _this$props2.button,
          children = _this$props2.children,
          className = _this$props2.className,
          height = _this$props2.height,
          heightIcon = _this$props2.heightIcon,
          isOpen = _this$props2.isOpen,
          last = _this$props2.last,
          nubbin = _this$props2.nubbin,
          onSelect = _this$props2.onSelect,
          position = _this$props2.position,
          renderClosedDropdown = _this$props2.renderClosedDropdown,
          renderHeader = _this$props2.renderHeader,
          size = _this$props2.size;
      var wrapperClasses = ['slds-dropdown-trigger', 'slds-dropdown-trigger_click', {
        'slds-button_last': last
      }, {
        'slds-is-open': isOpen
      }];
      var dropdownClasses = ['slds-dropdown', _defineProperty({}, "slds-dropdown_".concat(size), size), {
        'slds-dropdown_left': position.includes('left')
      }, {
        'slds-dropdown_right': position.includes('right')
      }, {
        'slds-dropdown_bottom': position.startsWith('bottom')
      }, _defineProperty({}, "slds-nubbin_".concat(position), nubbin), className];
      var listClasses = [_defineProperty({}, "slds-dropdown_length-".concat(height), height), _defineProperty({}, "slds-dropdown_length-with-icon-".concat(heightIcon), heightIcon), 'slds-dropdown__list'];
      var rest = omit(this.props, Object.keys(propTypes));
      return React.createElement("div", _extends({
        className: cx(wrapperClasses)
      }, rest), button, (isOpen || renderClosedDropdown) && React.createElement("div", {
        className: cx(dropdownClasses)
      }, renderHeader && renderHeader(), children && React.createElement("ul", {
        className: cx(listClasses),
        role: "menu",
        onClick: onSelect ? this.handleItemClick : null
      }, this.renderChildren())));
    }
  }]);

  return ControlledMenu;
}(Component);

_defineProperty(ControlledMenu, "defaultProps", {
  className: null,
  checkbox: false,
  height: null,
  heightIcon: null,
  isOpen: false,
  last: false,
  nubbin: false,
  onSelect: null,
  position: 'top-left',
  renderHeader: null,
  renderClosedDropdown: false,
  size: 'small'
});

ControlledMenu.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
export default ControlledMenu;
